@@ -30,6 +30,6 @@ def save_mail(link: Link):
         link: Link object representing the email address.
 
     """
-    with LOCK:
+    with LOCK:  # type: ignore
         with open(PATH, 'a') as file:
             print(link.url, file=file)
