@@ -264,7 +264,7 @@ def submit(api: str, domain: Domain, data: typing.Dict[str, typing.Any]):
     save_submit(domain, data)
 
 
-def submit_new_host(time: typing.Datetime, link: Link, partial: bool = False):
+def submit_new_host(time: typing.Datetime, link: Link, partial: bool = False, force: bool = False):
     """Submit new host.
 
     When a new host is discovered, the :mod:`darc` crawler will submit the
@@ -276,6 +276,8 @@ def submit_new_host(time: typing.Datetime, link: Link, partial: bool = False):
         link: Link object of submission.
         partial: If the data is not complete, i.e. failed when fetching
             ``robots.txt``, ``hosts.txt`` and/or sitemaps.
+        force: If the data is force re-fetched, i.e. cache expired when
+            checking with :func:`darc.db.have_hostname`.
 
     If :data:`~darc.submit.API_NEW_HOST` is :data:`None`, the data for submission
     will directly be save through :func:`~darc.submit.save_submit`.
@@ -287,6 +289,8 @@ def submit_new_host(time: typing.Datetime, link: Link, partial: bool = False):
         {
             // partial flag - true / false
             "$PARTIAL$": ...,
+            // force flag - true / false
+            "$FORCE$": ...,
             // metadata of URL
             "[metadata]": {
                 // original URL - <scheme>://<netloc>/<path>;<params>?<query>#<fragment>
@@ -360,8 +364,6 @@ def submit_new_host(time: typing.Datetime, link: Link, partial: bool = False):
                 proxy=Proxy[link.proxy.upper()],
                 discovery=time,
                 last_seen=time,
-                alive=False,
-                since=EPOCH,
             ))
 
             if robots is not None:
@@ -389,6 +391,7 @@ def submit_new_host(time: typing.Datetime, link: Link, partial: bool = False):
 
     data = {
         '$PARTIAL$': partial,
+        '$FORCE$': force,
         '[metadata]': metadata,
         'Timestamp': ts,
         'URL': link.host,
@@ -511,20 +514,16 @@ def submit_requests(time: typing.Datetime, link: Link,
     """
     if SAVE_DB:
         try:
-            model, _ = _db_operation(HostnameModel.get_or_create, hostname=link.host, defaults=dict(
+            model, model_created = _db_operation(HostnameModel.get_or_create, hostname=link.host, defaults=dict(
                 proxy=Proxy[link.proxy.upper()],
                 discovery=time,
                 last_seen=time,
-                alive=False,
-                since=EPOCH,
             ))
-            if not model.alive and response.ok:
-                model.alive = True
-                model.since = time
-            model.last_seen = time
-            _db_operation(model.save)
+            if not model_created:
+                model.last_seen = time
+                _db_operation(model.save)
 
-            url, _ = _db_operation(URLModel.get_or_create, hash=link.name, defaults=dict(
+            url, url_created = _db_operation(URLModel.get_or_create, hash=link.name, defaults=dict(
                 url=link.url,
                 hostname=model,
                 proxy=Proxy[link.proxy.upper()],
@@ -533,10 +532,14 @@ def submit_requests(time: typing.Datetime, link: Link,
                 alive=False,
                 since=EPOCH,
             ))
-            if not model.alive and response.ok:
+            if not url.alive and response.ok:
                 url.alive = True
                 url.since = time
-            url.last_seen = time
+            elif url.alive and not response.ok:
+                url.alive = False
+                url.since = time
+            if not url_created:
+                url.last_seen = time
             _db_operation(url.save)
 
             model = _db_operation(RequestsModel.create,
@@ -700,20 +703,16 @@ def submit_selenium(time: typing.Datetime, link: Link,
     """
     if SAVE_DB:
         try:
-            model, _ = _db_operation(HostnameModel.get_or_create, hostname=link.host, defaults=dict(
+            model, model_created = _db_operation(HostnameModel.get_or_create, hostname=link.host, defaults=dict(
                 proxy=Proxy[link.proxy.upper()],
                 discovery=time,
                 last_seen=time,
-                alive=True,
-                since=time,
             ))
-            if not model.alive:
-                model.alive = True
-                model.since = time
-            model.last_seen = time
-            _db_operation(model.save)
+            if not model_created:
+                model.last_seen = time
+                _db_operation(model.save)
 
-            url, _ = _db_operation(URLModel.get_or_create, hash=link.name, defaults=dict(
+            url, url_created = _db_operation(URLModel.get_or_create, hash=link.name, defaults=dict(
                 url=link.url,
                 hostname=model,
                 proxy=Proxy[link.proxy.upper()],
@@ -725,7 +724,8 @@ def submit_selenium(time: typing.Datetime, link: Link,
             if not url.alive:
                 url.alive = True
                 url.since = time
-            url.last_seen = time
+            if not url_created:
+                url.last_seen = time
             _db_operation(url.save)
 
             _db_operation(SeleniumModel.create,
